"""
BundestagTag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen
from requests import RequestException
from typing import List

from .bundestag_member_tag import BundestagMemberTag

class BundestagTag(sdkgen.TagAbstract):
    def __init__(self, http_client: requests.Session, parser: sdkgen.Parser):
        super().__init__(http_client, parser)

    def member(self) -> BundestagMemberTag:
        return BundestagMemberTag(
            self.http_client,
            self.parser
        )


