"""
autobahn_charging_station automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
from .autobahn_coordinate import AutobahnCoordinate
class AutobahnChargingStation(BaseModel):
    id: Optional[str] = Field(default=None, alias="id")
    title: Optional[str] = Field(default=None, alias="title")
    description: Optional[List[str]] = Field(default=None, alias="description")
    coordinate: Optional[AutobahnCoordinate] = Field(default=None, alias="coordinate")
    pass
