"""
warning automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
import datetime
class Warning(BaseModel):
    id: Optional[str] = Field(default=None, alias="id")
    severity: Optional[str] = Field(default=None, alias="severity")
    urgency: Optional[str] = Field(default=None, alias="urgency")
    type: Optional[str] = Field(default=None, alias="type")
    title: Optional[str] = Field(default=None, alias="title")
    start_date: Optional[datetime.datetime] = Field(default=None, alias="startDate")
    expires_date: Optional[datetime.datetime] = Field(default=None, alias="expiresDate")
    pass
